@@ -29,6 +29,9 @@ if get_platform() == "android":
     from .Interfaces import TCPInterface
     from .Interfaces import UDPInterface
     from .Interfaces import I2PInterface
+    from .Interfaces.Android import RNodeInterface
+    from .Interfaces.Android import SerialInterface
+    from .Interfaces.Android import KISSInterface
 else:
     from .Interfaces import *
 
@@ -911,7 +914,6 @@ class Reticulum:
                 
                 if mode == None:
                     mode = Interface.Interface.MODE_FULL
-                
                 interface.mode = mode
 
                 if configured_bitrate:
@@ -922,7 +924,7 @@ class Reticulum:
                 else:
                     interface.ifac_size = 8
 
-                interface.announce_cap = announce_cap
+                interface.announce_cap = announce_cap if announce_cap != None else Reticulum.ANNOUNCE_CAP/100.0
                 interface.announce_rate_target = announce_rate_target
                 interface.announce_rate_grace = announce_rate_grace
                 interface.announce_rate_penalty = announce_rate_penalty
